@@ -17,5 +17,7 @@ def set_current(version):
 
     """
     if custom_resource_api.get_all_by_template(version).count() == 0:
-        raise exceptions.ApiError("Please set custom resources to template before setting it to current.")
+        raise exceptions.ApiError(
+            "Please set custom resources to template before setting it to current."
+        )
     version_manager_api.set_current(version)
