@@ -4,7 +4,11 @@ Tree representation of refinement.
 
 from collections import OrderedDict
 
-from core_main_registry_app.constants import UNSPECIFIED_CATEGORY, CATEGORY_SUFFIX, UNSPECIFIED_LABEL
+from core_main_registry_app.constants import (
+    UNSPECIFIED_CATEGORY,
+    CATEGORY_SUFFIX,
+    UNSPECIFIED_LABEL,
+)
 
 
 class TreeInfo(object):
@@ -52,33 +56,40 @@ def build_tree(tree, element_name, element_display_name, enums, dot_query):
 
     """
     # Init tree.
-    type_refinement = TreeInfo(xsd_name=element_name,
-                               title=element_display_name)
+    type_refinement = TreeInfo(xsd_name=element_name, title=element_display_name)
     first_node = tree.setdefault(type_refinement, OrderedDict())
 
     # For each enumerations, we create the tree representation.
     for enum in enums:
         parent_node = first_node
-        levels = enum.attrib['value'].split(':')
+        levels = enum.attrib["value"].split(":")
 
         for i, level in enumerate(levels):
             # Create the tree info.
-            g = TreeInfo(xsd_name=level,
-                         title=level,
-                         path=dot_query,
-                         value=':'.join(levels[:i+1]))
+            g = TreeInfo(
+                xsd_name=level,
+                title=level,
+                path=dot_query,
+                value=":".join(levels[: i + 1]),
+            )
             g_node = parent_node.setdefault(g, OrderedDict())
             parent_node = g_node
 
             # Case where it is the last element of the enum
             # check if we are in the unspecified case
-            if len(levels)-1 == i and _check_case_unspecified(enums, enum, i, level):
+            if len(levels) - 1 == i and _check_case_unspecified(enums, enum, i, level):
                 # Case unspecified: create a new node for the unspecified node
-                title = "{0} {1}".format(UNSPECIFIED_LABEL, level) if UNSPECIFIED_CATEGORY else level
-                g = TreeInfo(xsd_name=level,
-                             title=title,
-                             path=dot_query,
-                             value=':'.join(levels[:i+1]))
+                title = (
+                    "{0} {1}".format(UNSPECIFIED_LABEL, level)
+                    if UNSPECIFIED_CATEGORY
+                    else level
+                )
+                g = TreeInfo(
+                    xsd_name=level,
+                    title=title,
+                    path=dot_query,
+                    value=":".join(levels[: i + 1]),
+                )
                 parent_node.setdefault(g, OrderedDict())
 
     return tree
@@ -98,11 +109,14 @@ def _check_case_unspecified(enums, current_enum, i, current_level):
     for enum in enums:
         # We work only on enums different to the current enum
         if current_enum != enum:
-            levels = enum.attrib['value'].split(':')
+            levels = enum.attrib["value"].split(":")
             # check if the current level is in the levels of the enum tested.
             # check if the current level is at the same position in the enum
             # check if the enum has more level
-            if current_level in levels and levels[i] == current_level \
-                    and len(current_enum.attrib['value']) < len(enum.attrib['value']):
+            if (
+                current_level in levels
+                and levels[i] == current_level
+                and len(current_enum.attrib["value"]) < len(enum.attrib["value"])
+            ):
                 return True
     return False
