@@ -13,13 +13,13 @@ def role_extraction(dict_content):
     Returns:
     """
     try:
-        list_resource_role = dict_content['Resource']['role']
+        list_resource_role = dict_content["Resource"]["role"]
         list_role = []
-        if '@xsi:type' in list_resource_role:
-            list_role.append(list_resource_role['@xsi:type'])
+        if "@xsi:type" in list_resource_role:
+            list_role.append(list_resource_role["@xsi:type"])
             return list_role
         for dict_role in list_resource_role:
-            list_role.append(dict_role['@xsi:type'])
+            list_role.append(dict_role["@xsi:type"])
         return list_role
     except Exception as e:
         raise exceptions.ModelError(str(e))
